#!/bin/env python3

#######################################################################
#
# Copyright (C) 2020 David Palao
#
# This file is part of FrUCToSA.
#
#  FrUCToSA is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  FrUCToSA is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with FrUCToSA.  If not, see <http://www.gnu.org/licenses/>.
#
#######################################################################

"""A dict to be used as template to generate the nodes Grafana dashboard 
in json format"""


node_template_dict = {
    "annotations": {
        "list": [
            {
                "builtIn": 1,
                "datasource": "-- Grafana --",
                "enable": True,
                "hide": True,
                "iconColor": "rgba(0, 211, 255, 1)",
                "name": "Annotations & Alerts",
                "type": "dashboard",
            }
        ]
    },
    "description": "node performance dashboard",
    "editable": True,
    "gnetId": None,
    "graphTooltip": 0,
    "links": [],
    "panels": [],
    "refresh": "10s",
    "schemaVersion": 19,
    "style": "dark",
    "tags": ["FrUCToSA"],
    "templating": {"list": []},
    "time": {"from": "now-6h", "to": "now"},
    "timepicker": {
        "refresh_intervals": [
            "5s",
            "10s",
            "30s",
            "1m",
            "5m",
            "15m",
            "30m",
            "1h",
            "2h",
            "1d",
        ],
        "time_options": ["5m", "15m", "1h", "6h", "12h", "24h", "2d", "7d", "30d"],
    },
    "timezone": "",
    "title": "{hostname}",
    "version": 0,
}

node_panels_template = [
    {
        "collapsed": False,
        "gridPos": {"h": 1, "w": 24, "x": 0, "y": 0},
        "id": 2,
        "panels": [],
        "title": "Global",
        "type": "row",
    },
    {
        "gridPos": {"h": 8, "w": 4, "x": 1, "y": 1},
        "id": 4,
        "options": {
            "fieldOptions": {
                "calcs": ["lastNotNull"],
                "defaults": {
                    "mappings": [],
                    "max": 100,
                    "min": 0,
                    "thresholds": [
                        {"color": "green", "value": None},
                        {"color": "red", "value": 80},
                    ],
                    "title": "$__series_name",
                    "unit": "percent",
                },
                "override": {},
                "values": False,
            },
            "orientation": "auto",
            "showThresholdLabels": False,
            "showThresholdMarkers": True,
        },
        "pluginVersion": "6.3.5",
        "targets": [
            {"refId": "A", "target": "averageSeries({hostname}.CPUPercent.*, *)"}
        ],
        "timeFrom": None,
        "timeShift": None,
        "title": "CPU",
        "type": "gauge",
    },
    {
        "gridPos": {"h": 8, "w": 4, "x": 5, "y": 1},
        "id": 6,
        "options": {
            "fieldOptions": {
                "calcs": ["lastNotNull"],
                "defaults": {
                    "mappings": [],
                    "max": 100,
                    "min": 0,
                    "thresholds": [
                        {"color": "green", "value": None},
                        {"color": "red", "value": 80},
                    ],
                    "title": "$__series_name",
                    "unit": "percent",
                },
                "override": {},
                "values": False,
            },
            "orientation": "auto",
            "showThresholdLabels": False,
            "showThresholdMarkers": True,
        },
        "pluginVersion": "6.3.5",
        "targets": [{"refId": "A", "target": "{hostname}.VirtualMemory.percent"}],
        "timeFrom": None,
        "timeShift": None,
        "title": "Virtual Memory",
        "type": "gauge",
    },
    {
        "gridPos": {"h": 8, "w": 4, "x": 9, "y": 1},
        "id": 8,
        "options": {
            "fieldOptions": {
                "calcs": ["lastNotNull"],
                "defaults": {
                    "mappings": [],
                    "max": 100,
                    "min": 0,
                    "thresholds": [
                        {"color": "green", "value": None},
                        {"color": "red", "value": 80},
                    ],
                    "title": "$__series_name",
                    "unit": "percent",
                },
                "override": {},
                "values": False,
            },
            "orientation": "auto",
            "showThresholdLabels": False,
            "showThresholdMarkers": True,
        },
        "pluginVersion": "6.3.5",
        "targets": [{"refId": "A", "target": "{hostname}.DiskUsage.percent"}],
        "timeFrom": None,
        "timeShift": None,
        "title": "Disk",
        "type": "gauge",
    },
    {
        "collapsed": False,
        "gridPos": {"h": 1, "w": 24, "x": 0, "y": 9},
        "id": 10,
        "panels": [],
        "title": "CPU",
        "type": "row",
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 10, "w": 16, "x": 1, "y": 10},
        "id": 12,
        "legend": {
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [
            {"refId": "A", "target": "averageSeries({hostname}.CPUPercent.*, *)"}
        ],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "Total CPU load",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "percent",
                "label": None,
                "logBase": 1,
                "max": "100",
                "min": "0",
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "description": "Percentage of CPU used on {hostname}",
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 9, "w": 16, "x": 1, "y": 20},
        "id": 14,
        "legend": {
            "alignAsTable": True,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "rightSide": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.CPUPercent.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "CPU percent",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "percent",
                "label": None,
                "logBase": 1,
                "max": "100",
                "min": "0",
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": "100",
                "min": "0",
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "description": "How the CPU time is divided into different operation modes",
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 11, "w": 16, "x": 1, "y": 29},
        "id": 16,
        "legend": {
            "alignAsTable": True,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "rightSide": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.CPUTimesPercent.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "CPU time",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "percent",
                "label": None,
                "logBase": 1,
                "max": "100",
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "description": "Interrupts and ctx switches",
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 8, "w": 16, "x": 1, "y": 40},
        "id": 18,
        "legend": {
            "alignAsTable": True,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "rightSide": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.CPUStats.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "CPU stats",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 8, "w": 16, "x": 1, "y": 48},
        "id": 20,
        "legend": {
            "alignAsTable": True,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "rightSide": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.CPUFreq.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "CPU Frequency",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "hertz",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "collapsed": False,
        "gridPos": {"h": 1, "w": 24, "x": 0, "y": 56},
        "id": 22,
        "panels": [],
        "title": "Network",
        "type": "row",
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 9, "w": 16, "x": 1, "y": 57},
        "id": 24,
        "legend": {
            "alignAsTable": True,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.NetIOCounters.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "Network IO counters",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "collapsed": False,
        "gridPos": {"h": 1, "w": 24, "x": 0, "y": 66},
        "id": 26,
        "panels": [],
        "title": "Memory",
        "type": "row",
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "description": "active, used, total, etc",
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 16, "w": 16, "x": 1, "y": 67},
        "id": 28,
        "legend": {
            "alignAsTable": True,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "rightSide": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.VirtualMemory.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "Virtual memory",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "bytes",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "collapsed": False,
        "gridPos": {"h": 1, "w": 24, "x": 0, "y": 83},
        "id": 30,
        "panels": [],
        "title": "Disk",
        "type": "row",
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 9, "w": 16, "x": 1, "y": 84},
        "id": 32,
        "legend": {
            "alignAsTable": False,
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.DiskUsage.percent"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "Disk Used",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "percent",
                "label": None,
                "logBase": 1,
                "max": "100",
                "min": "0",
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 9, "w": 16, "x": 1, "y": 93},
        "id": 34,
        "legend": {
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [
            {"refCount": 0, "refId": "A", "target": "{hostname}.DiskUsage.free"},
            {"refCount": 0, "refId": "B", "target": "{hostname}.DiskUsage.used"},
            {"refCount": 0, "refId": "C", "target": "{hostname}.DiskUsage.total"},
        ],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "Disk Usage",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "decbytes",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
    {
        "aliasColors": {},
        "bars": False,
        "dashLength": 10,
        "dashes": False,
        "fill": 1,
        "fillGradient": 0,
        "gridPos": {"h": 8, "w": 16, "x": 1, "y": 102},
        "id": 36,
        "legend": {
            "avg": False,
            "current": False,
            "max": False,
            "min": False,
            "show": True,
            "total": False,
            "values": False,
        },
        "lines": True,
        "linewidth": 1,
        "links": [],
        "nullPointMode": "null",
        "options": {"dataLinks": []},
        "percentage": False,
        "pointradius": 5,
        "points": False,
        "renderer": "flot",
        "seriesOverrides": [],
        "spaceLength": 10,
        "stack": False,
        "steppedLine": False,
        "targets": [{"refId": "A", "target": "{hostname}.DiskIOCounters.*"}],
        "thresholds": [],
        "timeFrom": None,
        "timeRegions": [],
        "timeShift": None,
        "title": "Global Disk parameters",
        "tooltip": {"shared": True, "sort": 0, "value_type": "individual"},
        "type": "graph",
        "xaxis": {
            "buckets": None,
            "mode": "time",
            "name": None,
            "show": True,
            "values": [],
        },
        "yaxes": [
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
            {
                "format": "short",
                "label": None,
                "logBase": 1,
                "max": None,
                "min": None,
                "show": True,
            },
        ],
        "yaxis": {"align": False, "alignLevel": None},
    },
]
